@@ -2,20 +2,20 @@ process_FUN <- function(FUN, use_fit = TRUE) {
   chk::chk_function(FUN)
   FUN_arg_names <- names(formals(FUN))
 
-  if (length(FUN_arg_names) == 0) {
+  if (is_null(FUN_arg_names)) {
     .err("`FUN` must accept one or more arguments")
   }
 
   attr(FUN, "use_coefs") <- any(FUN_arg_names == "coefs")
 
-  if (!use_fit && !attr(FUN, "use_coefs")) {
-    .err("`FUN` must accept a `coefs` argument. See help(\"sim_apply\") for details")
+  if (!use_fit && !.attr(FUN, "use_coefs")) {
+    .err('`FUN` must accept a `coefs` argument. See help("sim_apply") for details')
   }
 
   attr(FUN, "use_fit") <- any(FUN_arg_names == "fit")
 
-  if (!use_fit && attr(FUN, "use_fit")) {
-    .wrn("the `fit` argument to `FUN` will be ignored. See help(\"sim_apply\") for details")
+  if (!use_fit && .attr(FUN, "use_fit")) {
+    .wrn('the `fit` argument to `FUN` will be ignored. See help("sim_apply") for details')
     attr(FUN, "use_fit") <- FALSE
   }
 
@@ -23,7 +23,9 @@ process_FUN <- function(FUN, use_fit = TRUE) {
 }
 
 check_transform <- function(transform = NULL) {
-  if (is.null(transform)) return(NULL)
+  if (is_null(transform)) {
+    return(NULL)
+  }
 
   transform_name <- {
     if (is.character(transform)) transform
@@ -38,13 +40,13 @@ check_transform <- function(transform = NULL) {
 }
 
 check_valid_coef <- function(coef) {
-  length(coef) > 0 &&
+  is_not_null(coef) &&
     is.numeric(coef) &&
-    (is.null(dim(coef)) || (length(dim(coef)) == 2 && any(dim(coef) == 1)))
+    (is_null(dim(coef)) || (length(dim(coef)) == 2L && any(dim(coef) == 1L)))
 }
 
 check_valid_vcov <- function(vcov) {
-  length(vcov) > 0 &&
+  is_not_null(vcov) &&
     is.numeric(vcov) &&
     is.matrix(vcov) &&
     length(dim(vcov)) == 2L &&
@@ -53,8 +55,10 @@ check_valid_vcov <- function(vcov) {
 }
 
 check_symmetric_cov <- function(x) {
-  if (length(dim(x)) != 2 ||
-      !identical(dim(x)[1], dim(x)[2])) return(FALSE)
+  if (length(dim(x)) != 2L ||
+      !identical(dim(x)[1L], dim(x)[2L])) {
+    return(FALSE)
+  }
 
   r <- cov2cor(x)
 
@@ -70,32 +74,40 @@ check_coefs_vcov_length <- function(vcov, coefs, vcov_supplied, coef_supplied) {
         .err("the covariance matrix extracted from the model has dimensions different from the number of coefficients extracted from the model. You may need to supply your own function to extract one or both of these")
       }
       if (vcov_supplied == "fun") {
-        .err("the output of the function supplied to `vcov` must have dimensions equal to the number of coefficients extracted from the model (", length(coefs), ")")
+        .err(sprintf("the output of the function supplied to `vcov` must have dimensions equal to the number of coefficients extracted from the model (%s)",
+                     length(coefs)))
       }
       if (vcov_supplied == "num") {
-        .err("when supplied as a matrix, `vcov` must have dimensions equal to the number of coefficients extracted from the model (", length(coefs), ")")
+        .err(sprintf("when supplied as a matrix, `vcov` must have dimensions equal to the number of coefficients extracted from the model (%s)",
+                     length(coefs)))
       }
     }
     else if (coef_supplied == "fun") {
       if (vcov_supplied == "null") {
-        .err("the output of the function supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (", nrow(vcov), ")")
+        .err(sprintf("the output of the function supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (%s)",
+                     nrow(vcov)))
       }
       if (vcov_supplied == "fun") {
-        .err("the output of the function supplied to `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (", length(coefs), ")")
+        .err(sprintf("the output of the function supplied to `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (%s)",
+                     length(coefs)))
       }
       if (vcov_supplied == "num") {
-        .err("when supplied as a matrix, `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (", length(coefs), ")")
+        .err(sprintf("when supplied as a matrix, `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (%s)",
+                     length(coefs)))
       }
     }
     else if (coef_supplied == "num") {
       if (vcov_supplied == "null") {
-        .err("the coefficient vector supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (", nrow(vcov), ")")
+        .err(sprintf("the coefficient vector supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (%s)",
+                     nrow(vcov)))
       }
       if (vcov_supplied == "fun") {
-        .err("the output of the function supplied to `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (", length(coefs), ")")
+        .err(sprintf("the output of the function supplied to `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (%s)",
+                     length(coefs)))
       }
       if (vcov_supplied == "num") {
-        .err("when supplied as a matrix, `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (", length(coefs), ")")
+        .err(sprintf("when supplied as a matrix, `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (%s)",
+                     length(coefs)))
       }
     }
   }
@@ -132,38 +144,47 @@ check_coefs_vcov_length_mi <- function(vcov, coefs, vcov_supplied, coef_supplied
       paste0("imputation%s ", word_list(as.character(bad_imps)))
   }
 
-  if (length(bad_imps) > 0) {
+  if (is_not_null(bad_imps)) {
     if (coef_supplied == "null") {
       if (vcov_supplied == "null") {
-        .err("in ", in.imps, ", the covariance matrix extracted from the model has dimensions different from the number of coefficients extracted from the model. You may need to supply your own function to extract one or both of these", n = length(bad_imps))
+        .err("in ", in.imps, ", the covariance matrix extracted from the model has dimensions different from the number of coefficients extracted from the model. You may need to supply your own function to extract one or both of these",
+             n = length(bad_imps))
       }
       else if (vcov_supplied == "fun") {
-        .err("in ", in.imps, ", the output of the function supplied to `vcov` must have dimensions equal to the number of coefficients extracted from the model (", length(coefs[[1]]), ")", n = length(bad_imps))
+        .err("in ", in.imps, ", the output of the function supplied to `vcov` must have dimensions equal to the number of coefficients extracted from the model (", length(coefs[[1L]]), ")",
+             n = length(bad_imps))
       }
       else if (vcov_supplied == "num") {
-        .err("in ", in.imps, ", `vcov` must have dimensions equal to the number of coefficients extracted from the model (", length(coefs[[1]]), ") when supplied as a matrix or list of matrices", n = length(bad_imps))
+        .err("in ", in.imps, ", `vcov` must have dimensions equal to the number of coefficients extracted from the model (", length(coefs[[1L]]), ") when supplied as a matrix or list of matrices",
+             n = length(bad_imps))
       }
     }
     else if (coef_supplied == "fun") {
       if (vcov_supplied == "null") {
-        .err("in ", in.imps, ", the output of the function supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (", nrow(vcov[[1]]), ")", n = length(bad_imps))
+        .err("in ", in.imps, ", the output of the function supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (", nrow(vcov[[1L]]), ")",
+             n = length(bad_imps))
       }
       else if (vcov_supplied == "fun") {
-        .err("in ", in.imps, ", the output of the function supplied to `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (", length(coefs[[1]]), ")", n = length(bad_imps))
+        .err("in ", in.imps, ", the output of the function supplied to `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (", length(coefs[[1L]]), ")",
+             n = length(bad_imps))
       }
       else if (vcov_supplied == "num") {
-        .err("in ", in.imps, ", `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (", length(coefs[[1]]), ") when supplied as a matrix or list of matrices", n = length(bad_imps))
+        .err("in ", in.imps, ", `vcov` must have dimensions equal to the length of the output of the function supplied to `coefs` (", length(coefs[[1L]]), ") when supplied as a matrix or list of matrices",
+             n = length(bad_imps))
       }
     }
     else if (coef_supplied == "num") {
       if (vcov_supplied == "null") {
-        .err("in ", in.imps, ", the coefficient vector supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (", nrow(vcov[[1]]), ")", n = length(bad_imps))
+        .err("in ", in.imps, ", the coefficient vector supplied to `coefs` must have length equal to the dimensions of the covariance matrix extracted from the model (", nrow(vcov[[1L]]), ")",
+             n = length(bad_imps))
       }
       else if (vcov_supplied == "fun") {
-        .err("in ", in.imps, ", the output of the function supplied to `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (", length(coefs[[1]]), ")", n = length(bad_imps))
+        .err("in ", in.imps, ", the output of the function supplied to `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (", length(coefs[[1L]]), ")",
+             n = length(bad_imps))
       }
       else if (vcov_supplied == "num") {
-        .err("in ", in.imps, ", `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (", length(coefs[[1]]), ") when supplied as a matrix or list of matrices", n = length(bad_imps))
+        .err("in ", in.imps, ", `vcov` must have dimensions equal to the length of the coefficient vector supplied to `coefs` (", length(coefs[[1L]]), ") when supplied as a matrix or list of matrices",
+             n = length(bad_imps))
       }
     }
   }
@@ -171,28 +192,29 @@ check_coefs_vcov_length_mi <- function(vcov, coefs, vcov_supplied, coef_supplied
 
 check_fitlist <- function(fitlist) {
   if (!is.list(fitlist) ||
-      any(vapply(fitlist, function(f) {
-        b <- try(coef(f))
-        is_error(b) || is.null(b) || all(is.na(b))
-      }, logical(1L)))) {
+      any_apply(fitlist, function(f) {
+        b <- try(coef(f), silent = TRUE)
+        is_error(b) || is_null(b) || all(is.na(b))
+      })) {
     .err("`fitlist` must be a list of model fits or a `mira` object")
   }
 }
 
 check_ests.list <- function(est, test) {
   l <- lengths(est)
+  l0 <- which(l == 0L)
 
-  if (any(l == 0)) {
+  if (is_not_null(l0)) {
     .wrn("some simulations produced no estimates; these estimates have been replaced by `NA`",
          immediate = FALSE)
-    est[l == 0] <- lapply(which(l == 0), function(i) {
-      rep(NA_real_, length(test))
+
+    est[l0] <- lapply(l0, function(i) {
+      rep.int(NA_real_, length(test))
     })
   }
 
-  if (any(l != length(test))) {
-    .err("not all simulations produced estimates with the same length as the number of estimates computed from the original coefficients, indicating a problem in `FUN`",
-         immediate = FALSE)
+  if (!all(l == length(test))) {
+    .err("not all simulations produced estimates with the same length as the number of estimates computed from the original coefficients, indicating a problem in `FUN`")
   }
 }
 
@@ -201,7 +223,8 @@ check_ests <- function(ests) {
   if (length(non_finites) == length(ests)) {
     .err("no finite estimates were produced")
   }
-  if (length(non_finites) > 0) {
+
+  if (is_not_null(non_finites)) {
     .wrn("some non-finite values were found among the estimates, which can invalidate inferences",
          immediate = FALSE)
   }
@@ -209,7 +232,9 @@ check_ests <- function(ests) {
 
 process_parm <- function(object, parm) {
   #Returns numeric parm
-  if (missing(parm)) parm <- seq_len(ncol(object))
+  if (missing(parm)) {
+    parm <- seq_len(ncol(object))
+  }
 
   if (is.character(parm)) {
     ind <- match(parm, names(object))
@@ -222,13 +247,15 @@ process_parm <- function(object, parm) {
   }
   else if (is.numeric(parm)) {
     chk::chk_whole_numeric(parm)
+
     if (any(parm < 1) || any(parm > ncol(object))) {
-      if (ncol(object) != 1) {
-        .err(sprintf("all values in `parm` must be between 1 and %s", ncol(object)))
+      if (ncol(object) != 1L) {
+        .err(sprintf("all values in `parm` must be between 1 and %s",
+                     ncol(object)))
       }
 
       .wrn("ignoring `parm` because only one estimate is available")
-      parm <- 1
+      parm <- 1L
     }
   }
   else {
@@ -239,14 +266,16 @@ process_parm <- function(object, parm) {
 }
 
 process_null <- function(null, object, parm) {
-  if (length(null) == 0 || (is.atomic(null) && all(is.na(null)))) {
+  if (is_null(null) || (is.atomic(null) && all(is.na(null)))) {
     null <- NA_real_
   }
-  chk::chk_numeric(null)
+  else {
+    chk::chk_numeric(null)
+  }
 
-
-  if (!is.null(names(null))) {
-    null0 <- setNames(rep(NA_real_, length(parm)), names(object)[parm])
+  if (is_not_null(names(null))) {
+    null0 <- rep.int(NA_real_, length(parm)) |>
+      setNames(names(object)[parm])
 
     if (!all(names(null) %in% names(null0))) {
       if (all(seq_len(ncol(object)) %in% parm)) {
@@ -259,8 +288,9 @@ process_null <- function(null, object, parm) {
 
     null0[names(null)] <- null
   }
-  else if (length(null) == 1) {
-    null0 <- setNames(rep(null, length(parm)), names(object)[parm])
+  else if (length(null) == 1L) {
+    null0 <- rep.int(null, length(parm)) |>
+      setNames(names(object)[parm])
   }
   else if (length(null) == length(parm)) {
     null0 <- setNames(null, names(object)[parm])
@@ -278,37 +308,42 @@ check_classes <- function(olddata, newdata) {
   new <- vapply(newdata, stats::.MFclass, character(1L))
   old <- vapply(olddata, stats::.MFclass, character(1L))
   new <- new[names(new) %in% names(old)]
-  if (length(new) == 0L) return(invisible(NULL))
+
+  if (is_null(new)) {
+    return(invisible(NULL))
+  }
+
   old <- old[names(new)]
   old[old == "ordered"] <- "factor"
   new[new == "ordered"] <- "factor"
   new[old == "factor" & new == "character"] <- "factor"
   new[old == "character" & new == "factor"] <- "character"
 
-  if (identical(old, new)) {
-    return(invisible(NULL))
+  if (!identical(old, new)) {
+    wrong <- old != new
+    if (sum(wrong) == 1)
+      .err(sprintf("variable '%s' was fit with type %s but type %s was supplied",
+                   names(old)[wrong], add_quotes(old[wrong]), add_quotes(new[wrong])))
+    else
+      .err(sprintf("variables %s were specified with different types from the original model fit",
+                   word_list(names(old)[wrong], quotes = TRUE)))
   }
 
-  wrong <- old != new
-  if (sum(wrong) == 1)
-    .err(sprintf("variable '%s' was fit with type \"%s\" but type \"%s\" was supplied",
-                 names(old)[wrong], old[wrong], new[wrong]))
-  else
-    .err(sprintf("variables %s were specified with different types from the original model fit",
-                 word_list(names(old)[wrong], quotes = TRUE)))
+  invisible(NULL)
 }
 
 check_sim_apply_wrapper_ready <- function(sim) {
-  fun <- deparse1(pkg_caller_call()[[1]])
+  fun <- deparse1(pkg_caller_call()[[1L]])
 
   chk::chk_is(sim, "clarify_sim")
 
-  if (!isTRUE(attr(sim, "use_fit"))) {
+  if (!isTRUE(.attr(sim, "use_fit"))) {
     .err(sprintf("`%s()` can only be used when a model fit was supplied to the original call to `sim()`",
                  fun))
   }
+
   if (inherits(sim, "clarify_misim")) {
-    if (!all(vapply(sim$fit, insight::is_regression_model, logical(1L)))) {
+    if (!all_apply(sim$fit, insight::is_regression_model)) {
       .err(sprintf("`%s()` can only be used with regression models",
                    fun))
     }
